<?php
/**
 * Custom template tags for this theme
 * 
 */

if ( ! function_exists( 'industri_fonts_url' ) ) {

	function industri_fonts_url() {

		/**
	 	* google fonts url
	 	*
	 	* @since Industri 1.0
	 	*
	 	* @return void
	 	*/		

	 	$fonts_url = '';		

	 	$font_families = array('Roboto Slab:wght@100;200;300;400;500;600;700;800;900|Roboto:wght@300;400;500;700;900');		

	 	$query_args = array(
	 		'family' => urlencode( implode( '|', $font_families ) ),
	 		'subset' => urlencode( 'latin,latin-ext' ),
	 	);

	 	$fonts_url = add_query_arg( $query_args, '//fonts.googleapis.com/css' );

	 	return $fonts_url;
	 }
	}

	if ( ! function_exists( 'industri_post_comments_count' ) ) {
		// comments count
		function industri_post_comments_count($post_id){

			$args = array(
		    'post_id' => $post_id,   // Use post_id, not post_ID
		        'count'   => true // Return only the count
		    );
			$comments_count = get_comments( $args );
			echo sprintf( '<a href="%1$s" class="post-comment"><i class="fas fa-comment-dots"></i>&nbsp;%2$s</a>',
				esc_url(get_permalink( $post_id )),			
				esc_html($comments_count)		
			);


		}
	}


	if ( ! function_exists( 'industri_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *	 
	 */
	function industri_posted_on() {

		$time_string = 	'<time class="entry-date published
		updated" datetime="%1$s">%2$s </time>';	

		$time_string = sprintf( $time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )			
		);

		printf(
			/* translators: %s: Publish date. */
			esc_html__( '%s', 'industri' ),
			$time_string // phpcs:ignore WordPress.Security.EscapeOutput
		);

		// author details
		industri_posted_by();
	}
}

if ( ! function_exists( 'industri_posted_by' ) ) {
	/**
	 * Prints HTML with meta information about theme author.
	 * 
	 */
	function industri_posted_by() {

		$user = wp_get_current_user();

		echo sprintf( '<a href="%1$s"><i class="fa fa-user"></i> %3$s</a>',
			esc_url(get_author_posts_url( get_the_author_meta( 'ID' ) )),
			esc_url( get_avatar_url( $user->ID ) ),
			esc_html(get_the_author())
		);		
	}
}

if ( ! function_exists( 'industri_header_style' ) ) {
	/**
	 * Theme header style
	 * 
	 */
	function industri_header_style() {
		
		$header_style = get_theme_mod('header_layout','one' );

		if( 'one' == $header_style ){
			get_template_part( 'template-parts/headers/one-header-style' );			
		}
	}
}

if ( ! function_exists( 'industri_post_thumbnail' ) ) {
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 *
	 * @since Industri 1.0
	 *
	 * @return void
	 */
	function industri_post_thumbnail() {
		if ( ! industri_can_show_post_thumbnail() ) {
			return;
		}
		?>

		<?php if ( is_singular() ) : ?>
			
			<div class="post-thumbnail blog-item-img">
				<?php				
				the_post_thumbnail( 'post-thumbnail', array( 'loading' => false ) );
				?>				
			</div>

		<?php else : ?>

			<div class="post-thumbnail blog-item-img">
				<a class="post-thumbnail-inner alignwide" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
					<?php the_post_thumbnail( 'post-thumbnail' ); ?>
				</a>					
			</div>
		<?php endif; ?>
		<?php
	}
}

if ( ! function_exists( 'industri_can_show_post_thumbnail' ) ) {
	function industri_can_show_post_thumbnail() {
		return apply_filters(
			'industri_can_show_post_thumbnail',
			! post_password_required() && ! is_attachment() && has_post_thumbnail()
		);
	}

}	

if ( ! function_exists( 'industri_the_posts_navigation' ) ) {
	/**
	 * Print the next and previous posts navigation.
	 *
	 * @since Industri 1.0
	 *
	 * @return void
	 */
	function industri_the_posts_navigation() {		

		if( !paginate_links() ){
			return;
		}

		$args = array(			
			'mid_size'           => 2,
			'prev_next'          => true,
			'prev_text'          => __('<i class="fa fa-chevron-left"></i>','industri'),
			'next_text'          => __('<i class="fa fa-chevron-right"></i>','industri'),
			'type'               => 'list',				
		);

		echo ' <div class="pagination-wrap">';
		the_posts_pagination( $args );
		echo '</div>';		
	}
}

if( ! function_exists('industri_tages')){

	/**
	 * Prints HTML with meta information for the tags.	 
	 *
	 * @since Industri 1.0
	 *
	 * @return void
	 */

	function industri_tages(){
		$tags_list = get_the_tag_list( '', __( ', ', 'industri' ) );
		if ( $tags_list ) {
			echo sprintf(			
				'<a href="javascript:void(0)" class="post-tag"><i class="fa fa-tags"></i>%1$s</a>', $tags_list
			);
		}
	}
}

if ( ! function_exists( 'industri_entry_post_meta' ) ) {
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 * Footer entry meta is displayed differently in archives and single posts.
	 *
	 * @since Industri 1.0
	 *
	 * @return void
	 */
	function industri_entry_post_meta() {

		// Early exit if not a post.
		if ( 'post' !== get_post_type() ) {
			return;
		}

		// Hide meta information on pages.
		if ( ! is_single() ) {

			if ( is_sticky() ) {
				echo '<p>' . esc_html_x( 'Featured post', 'Label for sticky posts', 'industri' ) . '</p>';
			}			
			
			if ( has_category() || has_tag() ) {

				echo '<div class="post-taxonomies">';

				/* translators: used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( __( ', ', 'industri' ) );			

				if ( $categories_list ) {

					echo sprintf( '<a href="javascript:void(0)" class="post-tag"><i class="fas fa-layer-group"></i>%1$s</a>', 
						$categories_list
					);
				}

				/* translators: used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '', __( ', ', 'industri' ) );
				if ( $tags_list ) {
					echo sprintf(			
						'<a href="javascript:void(0)" class="post-tag"><i class="fas fa-tags"></i>%1$s</a>', $tags_list
					);
				}
				echo '</div>';
			}
		} else {			

			if ( has_category() || has_tag() ) {

				echo '<div class="post-taxonomies">';

				/* translators: used between list items, there is a space after the comma. */
				$categories_list = get_the_category_list( __( ', ', 'industri' ) );

				if ( $categories_list ) {

					echo sprintf( '<a href="javascript:void(0)" class="post-tag"><i class="fas fa-layer-group"></i>%1$s </a>', 
						$categories_list
					);

				}

				/* translators: used between list items, there is a space after the comma. */
				$tags_list = get_the_tag_list( '', __( ', ', 'industri' ) );
				if ( $tags_list ) {
					echo sprintf(			
						'<a href="javascript:void(0)" class="post-tag"><i class="fas fa-tags"></i>%1$s</a>', $tags_list
					);
				}
				echo '</div>';
			}
		}
	}
}




if ( ! function_exists( 'industri_dynamic_css' ) ) {
	/**
	* dynamic CSS
	*/
	function industri_dynamic_css(){		 

		$header_text_color = get_header_textcolor();
		$header_bg_image = get_header_image() ? get_header_image() : '';
		$breadcrumb_min_height = get_theme_mod('breadcrumb_min_height', 400);
		$breadcrumb_bg_img = get_theme_mod('breadcrumb_bg_image',esc_url(get_template_directory_uri() .'/assets/images/breadcrumb-bg.jpg'));

		$css = "h1.site-title a,p.site-description{
			color:#".$header_text_color.";
		}";

		// logo width
		$logo_width = get_theme_mod('logo_width','');
		$css =".logo img{width: ".$logo_width."px;}";

    	// header bg image
		$css .= "#main-header{
			background-image: url(".$header_bg_image.");
		}";

    	// breadcrumb bg
		$css .= ".breadcrumb-section{
			background-image: url(".$breadcrumb_bg_img.");
			min-height: ".$breadcrumb_min_height."px;
		}\n";

		// theme color
		$primary_color = get_theme_mod('theme_primary_color', '#f94b1a');
		$secondary_color = get_theme_mod('theme_secondary_color','#01013f' );  
		$css .= ":root {
			--ind-black: #050505;
			--ind-pink: #d63384;
			--ind-cyan: #17a2b8;
			--ind-white: #ffffff;
			--ind-gray-dark: #343a40;
			--ind-primary:". esc_attr( $primary_color ) .";
			--ind-primary-dark: #cc4911;
			--ind-primary-500: #f76a2e8c;
			--ind-secondary: ". esc_attr( $secondary_color ) .";
			--ind-secondary-500: #01013fb0;
			--ind-secondary-dark: #00012d;
			--ind-gray: #dedede;
			--ind-gray-light: #f7f8fc;
			--ind-gray-500: #f2f2f2;
			--ind-gray-500-thumb: #c2c2c2;
			--ind-danger: #dc3545;
			--ind-light: #fef1ec;
			--ind-dark: #343a40;
			--ind-theme-radius: 6.25rem;
			--ind-transition: all 0.8s;
			--ind-transition-slow: all 0.55s cubic-bezier(0.645, 0.045, 0.355, 1);
			--ind-transition-very-slow: all 0.75s cubic-bezier(0.645, 0.045, 0.355, 1);
		}";

		wp_add_inline_style( 'industri-style', $css );
	}

	add_action('wp_enqueue_scripts', 'industri_dynamic_css' );
}